summaryrefslogtreecommitdiff
path: root/src/mainboard/amd/solo/irq_tables.c
diff options
context:
space:
mode:
authorStefan Reinauer <stepan@openbios.org>2004-01-21 16:05:40 +0000
committerStefan Reinauer <stepan@openbios.org>2004-01-21 16:05:40 +0000
commitbd4be244bb0aa951f15dda2246a83f6da5734b55 (patch)
treee6b1ab3faa4428928bab37751b218bcd0dfac724 /src/mainboard/amd/solo/irq_tables.c
parentb020d53352c1bbe1084c9c499b45cfb345fc8677 (diff)
update mp table and pirq table
git-svn-id: svn://svn.coreboot.org/coreboot/trunk@1337 2b7e53f0-3cfb-0310-b3e9-8179ed1497e1
Diffstat (limited to 'src/mainboard/amd/solo/irq_tables.c')
-rw-r--r--src/mainboard/amd/solo/irq_tables.c75
1 files changed, 49 insertions, 26 deletions
diff --git a/src/mainboard/amd/solo/irq_tables.c b/src/mainboard/amd/solo/irq_tables.c
index feeace1605..ad397b6ecd 100644
--- a/src/mainboard/amd/solo/irq_tables.c
+++ b/src/mainboard/amd/solo/irq_tables.c
@@ -1,31 +1,54 @@
#include <arch/pirq_routing.h>
+#include <device/pci.h>
+
+#define IRQ_ROUTER_BUS 1
+#define IRQ_ROUTER_DEVFN PCI_DEVFN(5,0)
+#define IRQ_ROUTER_VENDOR 0x1022
+#define IRQ_ROUTER_DEVICE 0x7468
+#define IRQS_EXCLUSIVE 0x0c20
+#define IRQS_AVAILABLE 0xdeb8
+
+
+#define IRQ_SLOT(slot, bus, dev, fn, linka, linkb, linkc, linkd) \
+ { bus, (dev<<3)|fn, {{ linka, IRQS_AVAILABLE}, { linkb, IRQS_AVAILABLE}, \
+ {linkc, IRQS_AVAILABLE}, {linkd, IRQS_AVAILABLE}}, slot, 0}
+
+/* Each IRQ_SLOT entry consists of:
+ * bus, devfn, {link, bitmap}, {link, bitmap}, {link, bitmap}, {link, bitmap}, slot, rfu
+ */
const struct irq_routing_table intel_irq_routing_table = {
- PIRQ_SIGNATURE, /* u32 signature */
- PIRQ_VERSION, /* u16 version */
- 32+16*9, /* there can be total 9 devices on the bus */
- 1, /* Where the interrupt router lies (bus) */
- (5<<3)|3, /* Where the interrupt router lies (dev) */
- 0x0, /* IRQs devoted exclusively to PCI usage */
- 0x1022, /* Vendor */
- 0x7443, /* Device */
- 0, /* Crap (miniport) */
- { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }, /* u8 rfu[11] */
- 0xb0, /* u8 checksum , mod 256 checksum must give zero */
- { /* bus, devfn, {link, bitmap}, {link, bitmap}, {link, bitmap}, {link, bitmap}, slot, rfu */
- /* PCI Slot 1 */
- {0x02, (0x01<<3)|0, {{0x02, 0xdef8}, {0x03, 0xdef8}, {0x04, 0xdef8}, {0x01, 0xdef8}}, 0x01, 0},
- /* PCI Slot 2 */
- {0x02, (0x02<<3)|0, {{0x03, 0xdef8}, {0x04, 0xdef8}, {0x01, 0xdef8}, {0x02, 0xdef8}}, 0x02, 0},
- /* PCI Slot 3 */
- {0x01, (0x01<<3)|0, {{0x02, 0xdef8}, {0x03, 0xdef8}, {0x04, 0xdef8}, {0x01, 0xdef8}}, 0x03, 0},
- /* PCI Slot 4 */
- {0x01, (0x02<<3)|0, {{0x03, 0xdef8}, {0x04, 0xdef8}, {0x01, 0xdef8}, {0x02, 0xdef8}}, 0x04, 0},
- /* PCI Slot 5 */
- {0x03, (0x05<<3)|0, {{0x02, 0xdef8}, {0x03, 0xdef8}, {0x04, 0xdef8}, {0x01, 0xdef8}}, 0x05, 0},
- /* PCI Slot 6 */
- {0x03, (0x04<<3)|0, {{0x01, 0xdef8}, {0x02, 0xdef8}, {0x03, 0xdef8}, {0x04, 0xdef8}}, 0x06, 0},
- /* Let Linux know about bus 1 */
- {0x01, (0x05<<3)|3, {{0x00, 0xdef8}, {0x00, 0xdef8}, {0x00, 0xdef8}, {0x00, 0xdef8}}, 0x00, 0},
+ PIRQ_SIGNATURE, /* u32 signature */
+ PIRQ_VERSION, /* u16 version */
+ 32+16*IRQ_SLOT_COUNT, /* there can be total IRQ_SLOT_COUNT
+ * devices on the bus */
+ IRQ_ROUTER_BUS, /* Where the interrupt router lies (bus) */
+ IRQ_ROUTER_DEVFN, /* Where the interrupt router lies (dev) */
+ IRQS_EXCLUSIVE, /* IRQs devoted exclusively to PCI usage */
+ IRQ_ROUTER_VENDOR, /* Vendor */
+ IRQ_ROUTER_DEVICE, /* Device */
+ 0x00, /* Crap (miniport) */
+ { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }, /* u8 rfu[11] */
+ 0x00, /* u8 checksum , mod 256 checksum must give
+ * zero, will be corrected later
+ */
+ {
+
+ /* slot(0=onboard), devfn, irqlinks (line id, 0=not routed) */
+
+ /* PCI SLOT 1-4 */
+ IRQ_SLOT (1, 3,4,0, 1,2,3,4 ),
+ IRQ_SLOT (2, 3,5,0, 2,3,4,1 ),
+ IRQ_SLOT (3, 3,6,0, 3,4,1,2 ),
+ IRQ_SLOT (4, 3,7,0, 4,1,2,3 ),
+
+ /* Builtin Devices */
+ IRQ_SLOT (0, 3,0,0, 4,4,4,4 ), /* USB */
+ IRQ_SLOT (0, 1,5,1, 1,2,3,4 ), /* IDE */
+ IRQ_SLOT (0, 1,2,0, 1,2,3,4 ), /* AGP Bridge */
+
+ /* Let Linux know about bus 1 */
+ IRQ_SLOT (0, 1,5,0, 0,0,0,0 ),
+
}
};